###  A basic text widget, with scrollbars

text .text -yscrollcommand ".scroll set"
scrollbar .scroll -relief flat -command ".text yview"

pack append . .scroll {right filly} .text {expand fill}

.text insert current "This is a text widget, with an attached scrollbar.\n"
.text insert current "\n\n\n\nTry scrolling me."
