### Widgets embedded in a canvas

canvas .c1
pack append . .c1 {top expand fill}

.c1 create rectangle 20 20 80 80 -fill red
.c1 create rectangle 60 60 120 120 -fill green
.c1 create rectangle 40 40 100 100 -fill blue

button .c1.b1 -text "Embedded button"
.c1 create window 100 75 -window .c1.b1
