###  Basic geometry management with the packer (fill and expand options)

label .l1 -text "Label #1" -background red
label .l2 -text "Label #2" -background blue
label .l3 -text "Label #3" -background green

pack append . .l1 {top fill} .l2 {left fill} .l3 {bottom fill}
