### Canvases with scrollbars

canvas .c1 -scrollregion {-10c -10c 50c 20c}

.c1 create rectangle 100 100 400 400 -fill red
.c1 create rectangle 300 300 600 600 -fill green
.c1 create rectangle 200 200 500 500 -fill blue

scrollbar .s1 -command ".c1 yview" -relief sunk
scrollbar .s2 -orient horiz -command ".c1 xview" -relief sunk
pack append . .s2 {bottom fillx} .s1 {right filly} .c1 {expand fill}

.c1 config -xscroll ".s2 set" -yscroll ".s1 set"
