### Canvas item stacking

canvas .c1
pack append . .c1 {top expand fill}

set r1 [.c1 create rectangle 20 20 80 80 -fill red]
set r2 [.c1 create rectangle 60 60 120 120 -fill green]
set r3 [.c1 create rectangle 40 40 100 100 -fill blue]

.c1 bind $r1 <Button-1> ".c1 raise $r1"
.c1 bind $r2 <Button-1> ".c1 raise $r2"
.c1 bind $r3 <Button-1> ".c1 raise $r3"
