### Listbox with a scrollbar

scrollbar .scroll -command ".list yview"
listbox .list -yscroll ".scroll set"

pack append . .scroll {right filly} .list {left expand fill}

.list insert end "First list item"
.list insert end "Second list item"
.list insert end "Third list item"
