### Drawing in a Canvas (funky version)

canvas .c1
pack append . .c1 {top expand fill}

bind .c1 <ButtonPress-1> {set wid 0}

bind .c1 <B1-Motion> {
        .c1 create rectangle %x %y %x %y -width $wid
        incr wid
}
