### Menu options

menubutton .mbutton -text "Menu Button" -menu .mbutton.menu
pack append . .mbutton {top}

menu .mbutton.menu
.mbutton.menu add command -label "Open" -command "puts stdout open"
.mbutton.menu add command -label "Close" -state disabled
.mbutton.menu add cascade -label "More -->" -menu .mbutton.menu.more
.mbutton.menu add separator
.mbutton.menu add command -label "Exit"

menu .mbutton.menu.more
.mbutton.menu.more add command -label "Get" -command "puts stdout get"
.mbutton.menu.more add command -label "Put" -command "puts stdout put"
.mbutton.menu.more add command -label "Rename" -command "puts stdout rename"
