### Basic drop down menu

menubutton .mbutton -text "Menu Button" -menu .mbutton.menu
pack append . .mbutton {top}

menu .mbutton.menu
.mbutton.menu add command -label "Open"
.mbutton.menu add command -label "Close"
.mbutton.menu add separator
.mbutton.menu add command -label "Exit"
