### Canvas tags

canvas .c1
pack append . .c1 {top expand fill}

.c1 create rectangle 20 20 80 80 -fill red -tag cats
.c1 create rectangle 60 60 120 120 -fill green -tag cats
.c1 create rectangle 40 40 100 100 -fill blue -tag dogs

.c1 move cats 100 0
