### Canvas item types

canvas .c1
pack append . .c1 {top expand fill}

.c1 create arc 10 10 50 50 -fill red
.c1 create bitmap 100 50 -bitmap @bomb.xbm -background white
.c1 create line 10 100 40 140 -fill blue
.c1 create oval 150 150 170 200 -fill yellow
.c1 create polygon 200 10 210 50 280 20 -fill green
.c1 create rectangle 10 200 30 250 -fill cyan
.c1 create text 100 250 -text "Some random text"

