###  A set of radio button widgets

radiobutton .b1 -text "Red" -variable var1

radiobutton .b2 -text "Green" -variable var1

radiobutton .b3 -text "Blue" -variable var1

pack append . .b1 {top} .b2 {top} .b3 {top}
