###  A basic text widget, with tag bindings


text .text -yscrollcommand ".scroll set" -wrap word
scrollbar .scroll -relief flat -command ".text yview"

pack append . .scroll {right filly} .text {expand fill}

.text insert current "This is a text widget, with some tagged text:"
.text insert current "\n\n\n\n Press me! "

.text tag configure footag -relief raised -borderwidth 1 -background bisque
.text tag add footag {end linestart} end

.text tag bind footag <ButtonPress-1> {puts stdout "Gotcha!"}
