### Animation!

canvas .c1
pack append . .c1 {top expand fill}
.c1 create rectangle 10 10 40 40 -fill red -tag item

proc do-update {} {
        .c1 move item 1 1
        after 50 do-update
}
do-update

