###  A basic text widget, with word wrapping

text .text -wrap word
pack append . .text {top}

.text insert current "This is a text widget, displaying some text.\n"
.text insert current "Notice how lines are broken at words.\n"
